.. _naming:

Naming module
=======================

.. autoattribute:: DMT.core.naming.specifiers
    :no-value:

.. autoattribute:: DMT.core.naming.sub_specifiers
    :no-value:

.. autoattribute:: DMT.core.naming.specifiers_ss_para
    :no-value:

.. autoclass:: DMT.core.naming.SpecifierStr
    :members:
    :undoc-members:
    :show-inheritance:


.. autoclass:: DMT.core.naming._specifiers
    :members:
    :undoc-members:

.. autoclass:: DMT.core.naming._sub_specifiers
    :members:
    :undoc-members:

.. autoclass:: DMT.core.naming._specifiers_ss_para
    :members:
    :undoc-members:
